import { Injectable, ɵɵdefineInjectable, Component, NgModule } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { NavigationEnd, PRIMARY_OUTLET, ActivatedRoute, Router, RouterModule } from '@angular/router';
import { filter } from 'rxjs/operators';
import { map } from 'rxjs/internal/operators';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Ng7BootstrapBreadcrumbService {
    constructor() {
        this.breadcrumbLabels = new BehaviorSubject([]);
    }
    /**
     * @param {?} labels
     * @return {?}
     */
    updateBreadcrumbLabels(labels) {
        this.breadcrumbLabels.next(labels);
    }
}
Ng7BootstrapBreadcrumbService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
Ng7BootstrapBreadcrumbService.ctorParameters = () => [];
/** @nocollapse */ Ng7BootstrapBreadcrumbService.ngInjectableDef = ɵɵdefineInjectable({ factory: function Ng7BootstrapBreadcrumbService_Factory() { return new Ng7BootstrapBreadcrumbService(); }, token: Ng7BootstrapBreadcrumbService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Ng7BootstrapBreadcrumbComponent {
    /**
     * @param {?} activatedRoute
     * @param {?} router
     * @param {?} ng7BootstrapBreadcrumbService
     */
    constructor(activatedRoute, router, ng7BootstrapBreadcrumbService) {
        this.activatedRoute = activatedRoute;
        this.router = router;
        this.ng7BootstrapBreadcrumbService = ng7BootstrapBreadcrumbService;
        this.breadcrumb = [];
        this.breadCrumbData();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.ng7BootstrapBreadcrumbService.breadcrumbLabels.subscribe((/**
         * @param {?} labelData
         * @return {?}
         */
        (labelData) => {
            for (const label in labelData) {
                if (labelData.hasOwnProperty(label)) {
                    this.breadcrumb.map((/**
                     * @param {?} crumb
                     * @return {?}
                     */
                    (crumb) => {
                        /** @type {?} */
                        const labelParams = crumb.label.match(/[^{{]+(?=\}})/g);
                        if (labelParams) {
                            for (const labelParam of labelParams) {
                                /** @type {?} */
                                const dyanmicData = labelData[label];
                                if (labelParam === label) {
                                    crumb.label = crumb.label.replace('{{' + labelParam + '}}', dyanmicData);
                                }
                            }
                        }
                    }));
                }
            }
        }));
    }
    /**
     * @return {?}
     */
    breadCrumbData() {
        this.router.events
            .pipe(filter((/**
         * @param {?} event
         * @return {?}
         */
        event => event instanceof NavigationEnd)))
            .pipe(map((/**
         * @return {?}
         */
        () => this.activatedRoute)))
            .pipe(map((/**
         * @param {?} route
         * @return {?}
         */
        (route) => {
            while (route.firstChild) {
                route = route.firstChild;
            }
            return route;
        })))
            .pipe(filter((/**
         * @param {?} route
         * @return {?}
         */
        route => route.outlet === PRIMARY_OUTLET)))
            .subscribe((/**
         * @param {?} route
         * @return {?}
         */
        route => {
            if (route.snapshot.data.breadcrumb) {
                /** @type {?} */
                const breadcrumb = (JSON.parse(JSON.stringify(route.snapshot.data.breadcrumb)));
                breadcrumb.map((/**
                 * @param {?} crumb
                 * @return {?}
                 */
                (crumb) => {
                    /** @type {?} */
                    const urlChunks = crumb.url.split('/');
                    for (const chunk of urlChunks) {
                        if (chunk.includes(':')) {
                            /** @type {?} */
                            const paramID = chunk.replace(':', '');
                            /** @type {?} */
                            const routerParamID = route.snapshot.params[paramID];
                            crumb.url = crumb.url.replace(`:${paramID}`, routerParamID);
                        }
                    }
                    /** @type {?} */
                    const labelParams = crumb.label.match(/[^{{]+(?=\}})/g);
                    if (labelParams) {
                        for (const labelParam of labelParams) {
                            /** @type {?} */
                            const routerParamID = route.snapshot.params[labelParam.trim()];
                            if (routerParamID) {
                                crumb.label = crumb.label.replace('{{' + labelParam + '}}', routerParamID);
                            }
                        }
                    }
                }));
                this.breadcrumb = breadcrumb;
            }
            else {
                this.breadcrumb = [];
            }
        }));
    }
}
Ng7BootstrapBreadcrumbComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-ng7-bootstrap-breadcrumb',
                template: "<nav aria-label=\"breadcrumb\">\n    <ol class=\"breadcrumb\" *ngIf=\"breadcrumb.length\">\n        <ng-container *ngFor=\"let item of breadcrumb; let i = index\">\n            <li class=\"breadcrumb-item\" [ngClass]=\"{'active': breadcrumb.length !== i+1}\">\n                <a *ngIf=\"item?.url\" [routerLink]=\"item?.url\">{{ item.label }}</a>\n                <span *ngIf=\"!item?.url\">{{ item.label }}</span>\n            </li>\n        </ng-container>\n    </ol>\n</nav>\n",
                styles: [""]
            }] }
];
/** @nocollapse */
Ng7BootstrapBreadcrumbComponent.ctorParameters = () => [
    { type: ActivatedRoute },
    { type: Router },
    { type: Ng7BootstrapBreadcrumbService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Ng7BootstrapBreadcrumbModule {
}
Ng7BootstrapBreadcrumbModule.decorators = [
    { type: NgModule, args: [{
                declarations: [Ng7BootstrapBreadcrumbComponent],
                imports: [
                    RouterModule,
                    CommonModule
                ],
                exports: [Ng7BootstrapBreadcrumbComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { Ng7BootstrapBreadcrumbComponent, Ng7BootstrapBreadcrumbModule, Ng7BootstrapBreadcrumbService };
//# sourceMappingURL=ng7-bootstrap-breadcrumb.js.map
